pub enum RuntimeControl {
RequestStop,
Configure(ParameterSet<String, String>),
}Variants
RequestStop
Request the runtime to stop. It may take a while for the runtime to shut down as codelets will finish stepping and stop will be called for all active codelets.
Configure(ParameterSet<String, String>)
Requests a configuration change. Configuration changes will be applied after codelet step.