pub struct MessageTx<T> { /* private fields */ }Expand description
Message transmitter using a double-buffer queue
This is similar to DoubleBufferTx<Message<T>> with the main difference that
push automatically creates a Message.
Implementations
Sourceimpl<T> MessageTx<T>
impl<T> MessageTx<T>
Sourcepub fn new(capacity: usize) -> Self
pub fn new(capacity: usize) -> Self
Creates a new transmitter which can publish at most the given number of messages per step.
Sourcepub fn new_auto_size() -> Self
pub fn new_auto_size() -> Self
Creates a new transmitter which can publish an unbounded number of messages per step. Not recommended as it can lead to queues growing without bound.
Sourcepub fn push(&mut self, acqtime: Acqtime, value: T) -> Result<(), TxSendError>
pub fn push(&mut self, acqtime: Acqtime, value: T) -> Result<(), TxSendError>
Adds a Message to the transmitter with given acqtime and value. The message “pubtime” is set to the current time and the message sequence number is automatically incremented. Messages are published after the step functions concludes.
Sourcepub fn push_many<I: IntoIterator<Item = (Acqtime, T)>>(
&mut self,
values: I,
) -> Result<(), TxSendError>
pub fn push_many<I: IntoIterator<Item = (Acqtime, T)>>( &mut self, values: I, ) -> Result<(), TxSendError>
Adds multiple messages to the transmitter (see push).